Module: Ferret::Index
- Defined in:
- ext/isomorfeus_ferret_ext/frb_index.c
Overview
Summary
The Index module contains all the classes used for adding to and retrieving from the index. The important classes to know about are;
- FieldInfo
- FieldInfos
- IndexWriter
- IndexReader
- LazyDoc
The other classes in this module are useful for more advanced uses like building tag clouds, creating more-like-this queries, custom highlighting etc. They are also useful for index browsers.